@@ -1,20 +1,21 @@
 """This class is for handling wpiformat config files."""
 
-import os
-import sys
-
-import regex
+import re
+from pathlib import Path
 
 
 class Config:
-    def __init__(self, directory, file_name):
+    # Dict from filepath to file contents
+    __config_cache: dict[Path, list[str]] = {}
+
+    def __init__(self, directory: Path, filename: Path):
         """Constructor for Config object.
 
         Keyword arguments:
         directory -- directory in which to start search for file
-        file_name -- file name string
+        filename -- filename
         """
-        self.__config_dict = self.__parse_config_file(directory, file_name)
+        self.__config_dict = self.__parse_config_file(directory, filename)
         self.__c_header_include_regex = self.regex("cHeaderFileInclude")
         self.__cpp_header_include_regex = self.regex("cppHeaderFileInclude")
         self.__cpp_src_include_regex = self.regex("cppSrcFileInclude")
@@ -22,7 +23,7 @@ class Config:
         self.__modifiable_exclude_regex = self.regex("modifiableFileExclude")
 
     @staticmethod
-    def read_file(directory, file_name):
+    def read_file(directory: Path, filename: Path) -> tuple[Path, list[str]]:
         """Find file and return contents.
 
         Checks current directory for file. If one doesn't exist, try all parent
@@ -30,34 +31,39 @@ class Config:
 
         Keyword arguments:
         directory -- current directory from which to start search
-        file_name -- file name string
+        filename -- filename
 
-        Returns tuple of file name and list containing file contents or triggers
+        Returns tuple of filename and list containing file contents or triggers
         program exit.
         """
-        file_found = False
-        while not file_found:
+        for parent in (directory / filename).parents:
+            filepath = parent / filename
             try:
-                with open(directory + os.sep + file_name, "r") as file_contents:
-                    file_found = True
-                    return (
-                        os.path.join(directory, file_name),
-                        file_contents.read().splitlines(),
-                    )
-            except OSError:
-                # .git files are ignored, which are created within submodules
-                if os.path.isdir(directory + os.sep + ".git"):
-                    print(
-                        "error: config file '"
-                        + file_name
-                        + "' not found in '"
-                        + directory
-                        + "'"
-                    )
-                    sys.exit(1)
-                directory = os.path.dirname(directory)
+                # If filepath in config cache, return cached version instead
+                if config_file := Config.__config_cache.get(filepath):
+                    return filepath, config_file
 
-    def group(self, group_name):
+                with filepath.open("r") as file_contents:
+                    contents = file_contents.read().splitlines()
+                    Config.__config_cache[filepath] = contents
+
+                    # TODO: Remove deprecation message
+                    if filename.name.startswith(".styleguide"):
+                        new_name = filename.name.replace("styleguide", "wpiformat")
+                        print(
+                            f"warning: rename deprecated {filepath} to {filepath.with_name(new_name)}"
+                        )
+
+                    return filepath, contents
+            except OSError as e:
+                # .git files are ignored, which are created within submodules
+                if (parent / ".git").is_dir():
+                    raise OSError(
+                        f"config file '{filename}' not found in '{parent}'"
+                    ) from e
+        raise OSError(f"config file '{filename}' not found in '{directory}'")
+
+    def group(self, group_name: str) -> list[str]:
         """Returns value from config dictionary given key string.
 
         Keyword arguments:
@@ -71,7 +77,7 @@ class Config:
         except KeyError:
             return []
 
-    def regex(self, *args):
+    def regex(self, *args) -> re.Pattern:
         """Converts contents of group from config file into regex.
 
         Keyword arguments:
@@ -90,84 +96,86 @@ class Config:
 
         if len(group_contents) == 0:
             # If regex string is empty, make regex match nothing
-            return regex.compile(r"a^")
+            return re.compile(r"a^")
         else:
-            return regex.compile(r"|".join(group_contents))
+            return re.compile(r"|".join(group_contents))
 
-    def is_c_file(self, name):
+    def is_c_file(self, filename: Path) -> bool:
         """Returns True if file is either C header or C source file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.is_c_header_file(name) or self.is_c_src_file(name)
+        return self.is_c_header_file(filename) or self.is_c_src_file(filename)
 
-    def is_c_header_file(self, name):
+    def is_c_header_file(self, filename: Path) -> bool:
         """Returns True if file is C header file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.__c_header_include_regex.search(name) is not None
+        return self.__c_header_include_regex.search(filename.as_posix()) is not None
 
     @staticmethod
-    def is_c_src_file(name):
+    def is_c_src_file(filename: Path) -> bool:
         """Returns True if file is C source file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return name.endswith(".c")
+        return filename.suffix == ".c"
 
-    def is_cpp_file(self, name):
+    def is_cpp_file(self, filename: Path) -> bool:
         """Returns True if file is either C++ header or C++ source file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.is_cpp_header_file(name) or self.is_cpp_src_file(name)
+        return self.is_cpp_header_file(filename) or self.is_cpp_src_file(filename)
 
-    def is_cpp_header_file(self, name):
+    def is_cpp_header_file(self, filename: Path) -> bool:
         """Returns True if file is C++ header file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.__cpp_header_include_regex.search(name) is not None
+        return self.__cpp_header_include_regex.search(filename.as_posix()) is not None
 
-    def is_cpp_src_file(self, name):
+    def is_cpp_src_file(self, filename: Path) -> bool:
         """Returns True if file is C++ source file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.__cpp_src_include_regex.search(name) is not None
+        return self.__cpp_src_include_regex.search(filename.as_posix()) is not None
 
-    def is_header_file(self, name):
+    def is_header_file(self, filename: Path) -> bool:
         """Returns True if file is either C or C++ header file.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.is_c_header_file(name) or self.is_cpp_header_file(name)
+        return self.is_c_header_file(filename) or self.is_cpp_header_file(filename)
 
-    def is_generated_file(self, name):
+    def is_generated_file(self, filename: Path) -> bool:
         """Returns True if file is generated (generated files are skipped).
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.__generated_exclude_regex.search(name) is not None
+        return self.__generated_exclude_regex.search(filename.as_posix()) is not None
 
-    def is_modifiable_file(self, name):
+    def is_modifiable_file(self, filename: Path) -> bool:
         """Returns True if file is modifiable but should be skipped.
 
         Keyword arguments:
-        name -- file name string
+        filename -- filename
         """
-        return self.__modifiable_exclude_regex.search(name) is not None
+        return self.__modifiable_exclude_regex.search(filename.as_posix()) is not None
 
-    def __parse_config_file(self, directory, file_name):
+    def __parse_config_file(
+        self, directory: Path, filename: Path
+    ) -> dict[str, list[str]]:
         """Parse values from config file.
 
         Checks current directory for config file. If one doesn't exist, try all
@@ -175,7 +183,7 @@ class Config:
 
         Keyword arguments:
         directory -- current directory from which to start search
-        file_name -- config file name string
+        filename -- config filename
 
         Returns dictionary of groups (group name -> list of values).
         """
@@ -184,9 +192,9 @@ class Config:
         group_name = ""
         group_elements = []
 
-        self.file_name, lines = self.read_file(directory, file_name)
+        self.filename, lines = self.read_file(directory, filename)
         if not lines:
-            return None
+            return {}
 
         for line in lines:
             # Skip empty lines
@@ -205,22 +213,5 @@ class Config:
                 config_group[group_name] = group_elements
                 group_elements = []
             elif in_group:
-                value = line.strip()
-
-                # Header includes still use forward slash on Windows
-                unescaped_groups = [
-                    "includeRelated",
-                    "includeCSys",
-                    "includeCppSys",
-                    "includeOtherLibs",
-                    "includeProject",
-                ]
-                if group_name == "includeGuardRoots":
-                    # Include guard roots use native directory separators
-                    value = value.replace("/", os.sep)
-                elif group_name not in unescaped_groups and os.sep == "\\":
-                    # Replace "/" with escaped "\" for regexes on Windows
-                    value = value.replace("/", os.sep + os.sep)
-
-                group_elements.append(value)
+                group_elements.append(line.strip())
         return config_group
